'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _fs = require('fs');

var _child_process = require('child_process');

var _path = require('path');

exports.default = (argv, pkg) => {
  if (!argv.host && !argv.port && !argv.userId) throw new Error('Missing `--host` `--port` and `--userId`');
  if (!argv.host) throw new Error('Missing --hort');
  if (!argv.port) throw new Error('Missing --port');
  if (!argv.userId) throw new Error('Missing --userId');
  if (!argv.piUser) argv.piUser = 'pi';

  console.log(`Add user ${argv.piUser} if missing`);
  try {
    (0, _child_process.execSync)(`useradd ${argv.piUser} --create-home`, { stdio: 'inherit' });
  } catch (err) {}

  console.log(`Write /etc/systemd/system/${pkg.name}.service`);
  (0, _fs.writeFileSync)(`/etc/systemd/system/${pkg.name}.service`, `
[Unit]
Description=${pkg.description}
After=network.target
[Service]
Type=simple
WorkingDirectory=${(0, _path.dirname)(__dirname)}
ExecStart=${process.argv[0]} .
Restart=always
Environment=NODE_ENV=production
Environment=SERVER_PORT=${argv.port}
Environment=SERVER_HOST=${argv.host}
Environment=USER_ID=${argv.userId}
Environment=PI_USER=${argv.piUser}
Environment=WEB_PORT=${argv.webPort || 80}
SyslogIdentifier=${pkg.name}
[Install]
WantedBy=multi-user.target
`.trim());

  console.log('Enable and start systemctl service');
  (0, _child_process.execSync)(`systemctl enable ${pkg.name}`, { stdio: 'inherit' });
  (0, _child_process.execSync)(`systemctl start ${pkg.name}`, { stdio: 'inherit' });
};
//# sourceMappingURL=install.js.map