'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.screenshot = exports.off = exports.on = exports.getCurrentScreenState = undefined;

var _nightingale = require('nightingale');

var _nightingale2 = _interopRequireDefault(_nightingale);

var _scripts = require('./scripts');

var _client = require('./client');

var _display = require('./display');

var display = _interopRequireWildcard(_display);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const logger = new _nightingale2.default('app:screen');

/**
 * @returns {string} on|off|unavailable
 */
const state = () => (0, _scripts.runScript)('./screen.sh', ['state']);

let currentScreenState = state();
logger.info('init', { currentScreenState });

const getCurrentScreenState = exports.getCurrentScreenState = () => currentScreenState;

const on = exports.on = () => {
  logger.info('turning screen on');
  (0, _scripts.runScript)('./screen.sh', ['on']);
  currentScreenState = 'on';
  (0, _client.sendUpdate)({ screenState: currentScreenState });
  display.start();
};

const off = exports.off = () => {
  logger.info('turning screen off');
  (0, _scripts.runScript)('./screen.sh', ['off']);
  currentScreenState = 'off';
  (0, _client.sendUpdate)({ screenState: currentScreenState });
  display.stop();
};

if (currentScreenState === 'on') {
  process.nextTick(() => display.start());
}

const screenshot = exports.screenshot = () => {
  if (currentScreenState !== 'on') {
    logger.warn('screenshot: screen is off');
    return;
  }

  logger.info('getting screenshot');

  return (0, _scripts.pipeScript)('./screen.sh', ['screenshot']);
};
//# sourceMappingURL=screen.js.map