'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.runScript = runScript;
exports.pipeScript = pipeScript;
exports.spawn = spawn;
exports.listenScript = listenScript;

var _child_process = require('child_process');

var _nightingale = require('nightingale');

var _nightingale2 = _interopRequireDefault(_nightingale);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const logger = new _nightingale2.default('app:scripts');

const scriptDirname = `${__dirname}/../scripts/`;

function runScript(script, args, { cwd, uid, gid, env } = {}) {
  logger.debug('run script', { script, args, cwd, uid, gid, env });
  const result = (0, _child_process.spawnSync)(script, args, { cwd: cwd || scriptDirname, uid, gid, env });
  if (result.error) {
    logger.error(result.error.message);
  }

  if (result.stderr) {
    const stderr = result.stderr.toString();
    if (stderr) {
      logger.error(stderr, { script, args });
    }
  }

  if (result.stdout) {
    const stdout = result.stdout.toString().trim();
    logger.debug(stdout, { script, args });
    return stdout;
  }
}

function pipeScript(script, args, { cwd, uid, gid, env } = {}) {
  logger.debug('pipe script', { script, args, cwd, uid, gid, env });
  const result = (0, _child_process.spawnSync)(script, args, { cwd: cwd || scriptDirname, uid, gid, env });
  if (result.error) {
    logger.error(result.error.message);
  }

  if (result.stderr) {
    const stderr = result.stderr.toString();
    if (stderr) {
      logger.error(stderr, { script, args });
    }
  }

  if (result.stdout) {
    return result.stdout;
  }
}

function spawn(script, args, { cwd, uid, gid, env } = {}) {
  logger.debug('spawn', { script, args, cwd, uid, gid });
  return (0, _child_process.spawn)(script, args, { cwd: cwd || scriptDirname, uid, gid, env });
}

function listenScript(script, args, callbackOnData) {
  return new Promise((resolve, reject) => {
    const childProcess = spawn(script, args);
    childProcess.stdout.on('data', data => {
      data = data.toString();
      logger.debug(data);
      callbackOnData(data);
    });

    childProcess.stderr.on('data', data => {
      data = data.toString();
      logger.debug(data);
      callbackOnData(data);
    });

    childProcess.on('close', code => {
      if (code) {
        logger.error(`child process exited with code ${code}`);
        return reject(code);
      }

      resolve(code);
    });
  });
}
//# sourceMappingURL=scripts.js.map