'use strict';

require('alp-node/fetch');

var _nightingale = require('nightingale');

var _nightingale2 = _interopRequireDefault(_nightingale);

var _updateNotifier = require('update-notifier');

var _updateNotifier2 = _interopRequireDefault(_updateNotifier);

var _minimistArgv = require('minimist-argv');

var _minimistArgv2 = _interopRequireDefault(_minimistArgv);

var _package = require('../../package.json');

var _package2 = _interopRequireDefault(_package);

var _install = require('./install');

var _install2 = _interopRequireDefault(_install);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable no-console */
/* global fetch */
(0, _updateNotifier2.default)({ pkg: _package2.default }).notify();

if (_minimistArgv2.default.version) {
  console.log(_package2.default.version);
  process.exit(0);
}

const logger = new _nightingale2.default('cli');
(0, _nightingale.listenUnhandledErrors)(logger);

const action = _minimistArgv2.default._[0];

if (!action || _minimistArgv2.default.help) {
  console.log('Usage: cli <action> [args]');
  console.log('actions:');
  console.log('  - install: install systemd script');
  console.log('  - self-update');
  console.log('  - screen');
  console.log('      on: turn the screen on');
  console.log('      off: turn the screen off');
  console.log('      state: display the current state of the screen');
  console.log('  - display');
  console.log('      restart: restart the current display (twitch / ...)');
  console.log('      refresh: refresh the browser (only for chromimum)');
  console.log('      openbox-started: notify that openbox is started');
  process.exit(0);
}

const call = (requestUri, options, retry) => fetch(`http://localhost:${_minimistArgv2.default.webPort || '80'}/api/${requestUri}`, options).then(res => res.text()).then(res => console.log(res)).catch(err => {
  console.log(err.message || err);
  if (!retry) setTimeout(() => call(requestUri, options, true), 3000);
});

(() => {
  switch (action) {
    case 'install':
      {
        (0, _install2.default)(_minimistArgv2.default, _package2.default);
        break;
      }

    case 'self-update':
    case 'selfUpdate':
      return call('self-update', { method: 'POST' });

    case 'screen':
      switch (_minimistArgv2.default._[1]) {
        case undefined:
        case 'state':
          return call('screen');
        case 'on':
          return call('screen', { method: 'POST', body: JSON.stringify({ state: 'on' }) });
        case 'off':
          return call('screen', { method: 'POST', body: JSON.stringify({ state: 'on' }) });
      }
      throw new Error(`Unsupported screen instruction: ${_minimistArgv2.default._[1]}`);

    case 'display':
      switch (_minimistArgv2.default._[1]) {
        case undefined:
        case 'status':
          return call('display');
        case 'start':
          return call('display/start', { method: 'POST' });
        case 'openbox-started':
          return call('display/openbox-started', { method: 'POST' });
        case 'restart':
          return call('display/restart', { method: 'POST' });
        case 'refresh':
          return call('display/refresh', { method: 'POST' });
      }
      throw new Error(`Unsupported display instruction: ${_minimistArgv2.default._[1]}`);
  }

  throw new Error(`Unsupported instruction: ${action}`);
})();
//# sourceMappingURL=index.js.map