/* eslint-disable no-console */
/* global fetch */
import 'alp-node/fetch';
import Logger, { listenUnhandledErrors } from 'nightingale/src';
import updateNotifier from 'update-notifier';
import argv from 'minimist-argv';
import pkg from '../../package.json';
import install from './install';

updateNotifier({ pkg }).notify();

if (argv.version) {
  console.log(pkg.version);
  process.exit(0);
}

const logger = new Logger('cli');
listenUnhandledErrors(logger);

const action = argv._[0];

if (!action || argv.help) {
  console.log('Usage: cli <action> [args]');
  console.log('actions:');
  console.log('  - install: install systemd script');
  console.log('  - self-update');
  console.log('  - screen');
  console.log('      on: turn the screen on');
  console.log('      off: turn the screen off');
  console.log('      state: display the current state of the screen');
  console.log('  - display');
  console.log('      restart: restart the current display (twitch / ...)');
  console.log('      refresh: refresh the browser (only for chromimum)');
  console.log('      openbox-started: notify that openbox is started');
  process.exit(0);
}

const call = (requestUri, options, retry) => (
  fetch(`http://localhost:${argv.webPort || '80'}/api/${requestUri}`, options)
    .then(res => res.text())
    .then(res => console.log(res))
    .catch((err) => {
      console.log(err.message || err);
      if (!retry) setTimeout(() => call(requestUri, options, true), 3000);
    })
);

(() => {
  switch (action) {
    case 'install': {
      install(argv, pkg);
      break;
    }

    case 'self-update':
    case 'selfUpdate':
      return call('self-update', { method: 'POST' });

    case 'screen':
      switch (argv._[1]) {
        case undefined:
        case 'state':
          return call('screen');
        case 'on':
          return call('screen', { method: 'POST', body: JSON.stringify({ state: 'on' }) });
        case 'off':
          return call('screen', { method: 'POST', body: JSON.stringify({ state: 'on' }) });
      }
      throw new Error(`Unsupported screen instruction: ${argv._[1]}`);

    case 'display':
      switch (argv._[1]) {
        case undefined:
        case 'status':
          return call('display');
        case 'start':
          return call('display/start', { method: 'POST' });
        case 'openbox-started':
          return call('display/openbox-started', { method: 'POST' });
        case 'restart':
          return call('display/restart', { method: 'POST' });
        case 'refresh':
          return call('display/refresh', { method: 'POST' });
      }
      throw new Error(`Unsupported display instruction: ${argv._[1]}`);
  }

  throw new Error(`Unsupported instruction: ${action}`);
})();
