import Logger from 'nightingale';
import { runScript, pipeScript } from './scripts';
import { sendUpdate } from './client';
import * as display from './display';

const logger = new Logger('app:screen');

/**
 * @returns {string} on|off|unavailable
 */
const state = () => runScript('./screen.sh', ['state']);

let currentScreenState = state();
logger.info('init', { currentScreenState });

export const getCurrentScreenState = () => currentScreenState;

export const on = () => {
  logger.info('turning screen on');
  runScript('./screen.sh', ['on']);
  currentScreenState = 'on';
  sendUpdate({ screenState: currentScreenState });
  display.start();
};

export const off = () => {
  logger.info('turning screen off');
  runScript('./screen.sh', ['off']);
  currentScreenState = 'off';
  sendUpdate({ screenState: currentScreenState });
  display.stop();
};

if (currentScreenState === 'on') {
  process.nextTick(() => display.start());
}

export const screenshot = () => {
  if (currentScreenState !== 'on') {
    logger.warn('screenshot: screen is off');
    return;
  }

  logger.info('getting screenshot');

  return pipeScript('./screen.sh', ['screenshot']);
};
